@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/color.c,v 4.41 2001/08/06 21:38:58 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/color.c,v 4.43 2002/01/05 12:05:59 william Exp $
  */
 
 #define _INCLUDE_FROM_COLOR_C_
@@ -1868,27 +1868,31 @@ int UpdatePixel(ObjPtr, OldColorStr)
       if (from_pixels == NULL || to_pixels == NULL) FailAllocMessage();
       for (i=0; i < ncolors; i++) {
          from_pixels[i] = xpm_ptr->pixels[i];
-         index = QuickFindColorIndex(NULL, xpm_ptr->color_str[i],
-               &new_alloc, TRUE);
-         if (index == INVALID) {
-            sprintf(gszMsgBox,
-                  TgLoadCachedString(CSTID_CANNOT_ALLOC_COLOR_USE_ALT),
-                  xpm_ptr->color_str[i], colorMenuItems[colorIndex]);
-            Msg(gszMsgBox);
-            allocColorFailed = TRUE;
-
-            len = strlen(colorMenuItems[colorIndex]);
-            free(xpm_ptr->color_str[i]);
-            xpm_ptr->color_str[i] = (char*)malloc((len+1)*sizeof(char));
-            if (xpm_ptr->color_str[i] == NULL) FailAllocMessage();
-            strcpy(xpm_ptr->color_str[i], colorMenuItems[colorIndex]);
-
-            xpm_ptr->pixels[i] = colorPixels[colorIndex];
+         if (xpm_ptr->pixels[i] == (-1)) {
+            /* transparent pixel */
          } else {
-            if (xpm_ptr->pixels[i] != colorPixels[index]) {
-               changed = TRUE;
+            index = QuickFindColorIndex(NULL, xpm_ptr->color_str[i],
+                  &new_alloc, TRUE);
+            if (index == INVALID) {
+               sprintf(gszMsgBox,
+                     TgLoadCachedString(CSTID_CANNOT_ALLOC_COLOR_USE_ALT),
+                     xpm_ptr->color_str[i], colorMenuItems[colorIndex]);
+               Msg(gszMsgBox);
+               allocColorFailed = TRUE;
+
+               len = strlen(colorMenuItems[colorIndex]);
+               free(xpm_ptr->color_str[i]);
+               xpm_ptr->color_str[i] = (char*)malloc((len+1)*sizeof(char));
+               if (xpm_ptr->color_str[i] == NULL) FailAllocMessage();
+               strcpy(xpm_ptr->color_str[i], colorMenuItems[colorIndex]);
+
+               xpm_ptr->pixels[i] = colorPixels[colorIndex];
+            } else {
+               if (xpm_ptr->pixels[i] != colorPixels[index]) {
+                  changed = TRUE;
+               }
+               xpm_ptr->pixels[i] = colorPixels[index];
             }
-            xpm_ptr->pixels[i] = colorPixels[index];
          }
          to_pixels[i] = xpm_ptr->pixels[i];
       }
