@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/cursor.c,v 4.10 2001/08/06 21:39:00 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/cursor.c,v 4.12 2002/01/05 02:47:59 william Exp $
  */
 
 #define _INCLUDE_FROM_CURSOR_C_
@@ -38,6 +38,7 @@
 #include "choice.e"
 #include "color.e"
 #include "cursor.e"
+#include "file.e"
 #include "setup.e"
 #include "strtbl.e"
 #include "xbitmap.e"
@@ -265,9 +266,11 @@ void SetNullCursor(window)
 void SetWatchCursor(window)
    Window window;
 {
-   XDefineCursor(mainDisplay, window, watchCursor);
-   if (window == mainWindow) watchCursorOnMainWindow = TRUE;
-   XSync(mainDisplay, False);
+   if (!PRTGIF || cmdLineOpenDisplay) {
+      XDefineCursor(mainDisplay, window, watchCursor);
+      if (window == mainWindow) watchCursorOnMainWindow = TRUE;
+      XSync(mainDisplay, False);
+   }
 }
 
 void SetDrawCursor(window)
