@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/eps.c,v 4.30 2001/08/06 21:39:01 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/eps.c,v 4.32 2002/01/05 02:48:00 william Exp $
  */
 
 #define _INCLUDE_FROM_EPS_C_
@@ -480,8 +480,10 @@ int ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname, xbm_sz)
    if (fseek(fp, tiff_offset, SEEK_SET) != 0) {
       return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
    }
+   if (MkTempFile(tiff_fname, sizeof(tiff_fname), tmpDir, TOOL_NAME) == NULL) {
+      return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
+   }
    /* do not translate -- program constants */
-   MkTempFile(tiff_fname, sizeof(tiff_fname), tmpDir, TOOL_NAME);
    if ((tiff_fp=fopen(tiff_fname, "w")) == NULL) {
       return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
    }
@@ -501,7 +503,9 @@ int ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname, xbm_sz)
    tiff_fp = NULL;
 
    /* convert TIFF to XBM */
-   MkTempFile(xbm_fname, xbm_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(xbm_fname, xbm_sz, tmpDir, TOOL_NAME) == NULL) {
+      return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
+   }
    if ((xbm_fp=fopen(xbm_fname, "w")) == NULL) {
       return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
    }
@@ -614,7 +618,9 @@ FILE *GetTiffEPSIInfo(fp, pszEPS, file_buf_sz, pnPreviewOK)
       if (fseek(fp, 0x1e, SEEK_SET) != 0) {
          return ErrorInGetTiffEPSIInfo(fp, NULL, NULL);
       }
-      MkTempFile(pszEPS, file_buf_sz, tmpDir, TOOL_NAME);
+      if (MkTempFile(pszEPS, file_buf_sz, tmpDir, TOOL_NAME) == NULL) {
+         return ErrorInGetTiffEPSIInfo(fp, NULL, NULL);
+      }
       if ((eps_fp=fopen(pszEPS, "w")) == NULL) {
          return ErrorInGetTiffEPSIInfo(fp, NULL, NULL);
       }
@@ -697,7 +703,9 @@ int ConvertPsToXbm(pszPsPath, pszXbmPath, file_buf_sz)
    char *pszCmd=NULL, szBuf[MAXSTRING];
    int bytes_read=0;
 
-   MkTempFile(pszXbmPath, file_buf_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(pszXbmPath, file_buf_sz, tmpDir, TOOL_NAME) == NULL) {
+      return FALSE;
+   }
    pszCmd = (char*)malloc(
          (strlen(psToXbmCmd)+strlen(pszPsPath)+10)*sizeof(char));
    if (pszCmd == NULL) {
@@ -1132,7 +1140,11 @@ FILE *JustGetTiffEPSIInfo(fp, pszEPS, file_buf_sz)
    }
    eps_sz = ReadDoubleWord(&buf[0x08]);
 
-   MkTempFile(pszEPS, file_buf_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(pszEPS, file_buf_sz, tmpDir, TOOL_NAME) == NULL) {
+      fclose(fp);
+      unlink(pszEPS);
+      return NULL;
+   }
    if ((eps_fp=fopen(pszEPS, "w")) == NULL) {
       fclose(fp);
       unlink(pszEPS);
