@@ -5,7 +5,7 @@
  *
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -32,7 +32,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/http.c,v 4.21 2001/08/06 21:39:04 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/http.c,v 4.25 2002/02/22 22:58:35 william Exp $
  */
 
 #define _INCLUDE_FROM_HTTP_C_
@@ -759,6 +759,17 @@ int HttpDoWrite(n_socket, psz_path, psz_host, us_port)
    sprintf(msg, TgLoadCachedString(CSTID_SENDING_REQUESTS_DOTS), "HTTP");
    ShowRemoteStatus(msg);
 
+   if (debugHttp == 999 || ((debugHttp % 100) == 99 && cmdLineDumpURL &&
+         cmdLineDumpURLWithHeader)) {
+      /* debug, do not translate */
+      fprintf(stderr, "************************\n");
+      fprintf(stderr, "* Begin Request Header *\n");
+      fprintf(stderr, "************************\n");
+      fwrite(buf, sizeof(char), strlen(buf), stderr);
+      fprintf(stderr, "************************\n");
+      fprintf(stderr, "*  End Request Header  *\n");
+      fprintf(stderr, "************************\n");
+   }
    status = TcpDoWrite(n_socket, buf, (int)strlen(buf));
    free(buf);
 
@@ -779,7 +790,7 @@ void DebugHttpDumpResponse(buf)
    char *c_ptr=strchr(buf, '\n'), *line_ptr=buf, *content_type=NULL;
    int content_length=(-1), gif87a=FALSE;
    int len1=strlen(SZ_CONTENT_TYPE), len2=strlen(SZ_CONTENT_LENGTH);
-   FILE *fp=stdout;
+   FILE *fp=stderr;
 
    while (c_ptr != NULL) {
       char *prev_ptr=c_ptr;
@@ -1023,7 +1034,7 @@ char *HttpExtractText(buf, pn_buf_sz, pn_html, ppsz_content_type)
    char *c_ptr=strchr(buf, '\n'), *line_ptr=buf, *content_type=NULL;
    int content_length=(-1), text_type=FALSE, first_line=TRUE;
    int len1=strlen(SZ_CONTENT_TYPE), len2=strlen(SZ_CONTENT_LENGTH);
-   FILE *fp=stdout;
+   FILE *fp=stderr;
 
    CleanUpHttpHeaderInfo();
 
@@ -1041,7 +1052,8 @@ char *HttpExtractText(buf, pn_buf_sz, pn_html, ppsz_content_type)
          *c_ptr = '\0';
       }
       if (debugHttp > 0) {
-         if (debugHttp == 99 && cmdLineDumpURL && !cmdLineDumpURLWithHeader) {
+         if ((debugHttp % 100) == 99 && cmdLineDumpURL &&
+               !cmdLineDumpURLWithHeader) {
          } else if (!deserializingFile) {
             fprintf(fp, "%s\n", line_ptr);
          }
@@ -1356,12 +1368,12 @@ int HttpDoRead(n_socket, ppsz_buf, pn_buf_sz)
       *ppsz_buf = buf;
       if (pn_buf_sz != NULL) *pn_buf_sz = len;
       sprintf(msg, TgLoadCachedString(CSTID_RESPONSES_RECEIVED), "HTTP");
-      if (debugHttp == 99) {
+      if ((debugHttp % 100) == 99) {
          /* debug, do not translate */
          if (!cmdLineDumpURL) {
-            fprintf(stdout, "\n==========>>>\n");
-            fwrite(buf, sizeof(char), len, stdout);
-            fprintf(stdout, "\n<<<==========\n");
+            fprintf(stderr, "\n==========>>>\n");
+            fwrite(buf, sizeof(char), len, stderr);
+            fprintf(stderr, "\n<<<==========\n");
          }
       }
    } else {
