@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/import.c,v 4.67 2001/08/11 22:04:02 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/import.c,v 4.70 2002/02/26 01:05:47 william Exp $
  */
 
 #define _INCLUDE_FROM_IMPORT_C_
@@ -920,7 +920,9 @@ int ConvertGifToXpm(pszGifPath, pszXpmPath, xpm_path_sz)
    int bytes_read;
 
    InitGifToXpm();
-   MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME) == NULL) {
+      return FALSE;
+   }
    pszCmd = (char*)malloc(
          (strlen(gifToXpmCmd)+strlen(pszGifPath)+10)*sizeof(char));
    if (pszCmd == NULL) {
@@ -1053,7 +1055,9 @@ int ConvertPngToXpm(pszPngPath, pszXpmPath, xpm_path_sz)
    int bytes_read;
 
    InitGifToXpm();
-   MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME) == NULL) {
+      return FALSE;
+   }
    pszCmd = (char*)malloc(
          (strlen(pngToXpmCmd)+strlen(pszPngPath)+10)*sizeof(char));
    if (pszCmd == NULL) {
@@ -1186,7 +1190,9 @@ int ConvertJpegToXpm(pszJpegPath, pszXpmPath, xpm_path_sz)
    int bytes_read;
 
    InitGifToXpm();
-   MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME) == NULL) {
+      return FALSE;
+   }
    pszCmd = (char*)malloc(
          (strlen(jpegToXpmCmd)+strlen(pszJpegPath)+10)*sizeof(char));
    if (pszCmd == NULL) {
@@ -1400,7 +1406,9 @@ int ConvertAnyToXpm(pii, pszAnyPath, pszXpmPath, xpm_path_sz)
    char *pszCmd=NULL, szBuf[MAXSTRING];
    int bytes_read;
 
-   MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME);
+   if (MkTempFile(pszXpmPath, xpm_path_sz, tmpDir, TOOL_NAME) == NULL) {
+      return FALSE;
+   }
    pszCmd =
          (char*)malloc((strlen(pii->cmd)+strlen(pszAnyPath)+10)*sizeof(char));
    if (pszCmd == NULL) {
@@ -1703,7 +1711,10 @@ void ImportGIFToXPixmapDeck()
       ExposeEventHandler(&ev, TRUE);
    }
    if (!remote_file) {
-      MkTempFile(tmp_fname, sizeof(tmp_fname), tmpDir, TOOL_NAME);
+      if (MkTempFile(tmp_fname, sizeof(tmp_fname), tmpDir, TOOL_NAME) == NULL) {
+         importingFile = FALSE;
+         return;
+      }
       if (UtilCopyFile(gif_fname, tmp_fname) != TG_REMOTE_STATUS_OK) {
          sprintf(gszMsgBox, TgLoadString(STID_CANT_CREATE_NAMED_TMP_FILE),
                tmp_fname);
@@ -1719,7 +1730,7 @@ void ImportGIFToXPixmapDeck()
          (remote_file ? tmp_fname : gif_fname));
    SetWatchCursor(drawWindow);
    SetWatchCursor(mainWindow);
-   rc = ExecuteCmd(cmd);
+   rc = ExecuteCmd(cmd, FALSE);
    SetDefaultCursor(mainWindow);
    ShowCursor();
    if (!rc) {
@@ -2673,8 +2684,9 @@ void ImportCapturedImage()
    SetWatchCursor(drawWindow);
    SetWatchCursor(mainWindow);
 
-   MkTempFile(tmp_fname, sizeof(tmp_fname), tmpDir, TOOL_NAME);
-
+   if (MkTempFile(tmp_fname, sizeof(tmp_fname), tmpDir, TOOL_NAME) == NULL) {
+      return;
+   }
    if (installedColormaps != NULL) {
       saved_colormap = mainColormap;
       mainColormap = (*installedColormaps);
