@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/mainloop.c,v 4.80 2001/10/14 18:02:05 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/mainloop.c,v 4.96 2002/03/08 00:28:35 william Exp $
  */
 
 #define _INCLUDE_FROM_MAINLOOP_C_
@@ -124,6 +124,7 @@ char	geometrySpec[80];
 char	*displayName=NULL;
 int	initializingMain=FALSE;
 int	cmdLineUseXlib=FALSE;
+int	cmdLineVersion=FALSE;
 
 int			numExtraWins=0;
 struct WinInfoRec	*extraWinInfo=NULL;
@@ -553,7 +554,10 @@ char *GunzipFileIntoTemp(gzipped_fname)
       FailAllocMessage();
       return NULL;
    }
-   MkTempFile(tmp_fname, (strlen(tmpDir)+19)*sizeof(char), tmpDir, TOOL_NAME);
+   if (MkTempFile(tmp_fname, (strlen(tmpDir)+19)*sizeof(char), tmpDir,
+         TOOL_NAME) == NULL) {
+      return NULL;
+   }
    if ((out_fp=fopen(tmp_fname, "w")) == NULL) {
       sprintf(gszMsgBox, TgLoadString(STID_CANNOT_OPEN_FILE_FOR_WRITING),
             tmp_fname);
@@ -918,6 +922,7 @@ int JustLoadAFile(pszFile, pnNeedToCheckAutoExec, nAttemptToMerge, pnAbortMerge)
       foundGoodStateObject = FALSE;
       while ((read_status=ReadObj(fp, &obj_ptr)) == TRUE) {
          if (obj_ptr != NULL) {
+            obj_ptr->tmp_parent = NULL;
             AdjForOldVersion(obj_ptr);
             AddObj(NULL, topObj, obj_ptr);
          }
@@ -972,6 +977,7 @@ int JustLoadAFile(pszFile, pnNeedToCheckAutoExec, nAttemptToMerge, pnAbortMerge)
          if (file_is_remote) {
             sprintf(gszMsgBox, TgLoadCachedString(CSTID_CUR_FILE_IS),
                   remote_fname);
+            RedrawDrawWindow(botObj);
          } else if (short_name) {
             sprintf(gszMsgBox, TgLoadCachedString(CSTID_CUR_FILE_IS), rest);
          } else {
@@ -1236,7 +1242,9 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
 void HandleDataInMBuff()
 {
 #ifdef _TGIF_WB2
-   TryHandleWBInputData();
+   if (gstWBInfo.do_whiteboard) {
+      TryHandleWBInputData();
+   }
 #endif /* _TGIF_WB2 */
 }
 
@@ -1245,7 +1253,13 @@ int GetAnXEvent(pXEvent)
    XEvent *pXEvent;
 {
 #ifdef _TGIF_WB2
+   int rc=TRUE;
+
    gstWBInfo.BlockRemoteCmdDepth--;
+#ifdef DEBUG0
+   fprintf(stderr,"BlockRemoteCmdDepth (GetAnXEvent): %d\n",
+         gstWBInfo.BlockRemoteCmdDepth);
+#endif /* DEBUG0 */
    if (gnInputMethod != TGIM_NONE && tgIMExpectNextEvent(mainDisplay,
          drawWindow)) {
       if (!tgIMHandleNextEvent(mainDisplay, drawWindow, pXEvent)) {
@@ -1264,8 +1278,8 @@ int GetAnXEvent(pXEvent)
          timeout.tv_usec = 0;
 
          FD_ZERO(&fdset);
-         FD_SET(select_width-1, &fdset);
-         FD_SET(talkToSelfFiledes[0], &fdset);
+         FD_SET(select_width-1, &fdset); /* X file descriptor */
+         FD_SET(talkToSelfFiledes[0], &fdset); /* pipe */
 #ifdef __hpux
          status = select(nfds, (int*)&fdset, NULL, NULL, &timeout);
 #else /* !__hpux */
@@ -1275,10 +1289,10 @@ int GetAnXEvent(pXEvent)
             sprintf(gszMsgBox, TgLoadString(STID_FUNC_SELECT_SYS_CALL_FAILED),
                   "WaitForEvent()"),
             fprintf(stderr, "%s\n", gszMsgBox);
-            return FALSE;
+            rc = FALSE;
          } else if (status == 0) {
             /* timeout */
-            return FALSE;
+            rc = FALSE;
          } else if (status == 1) {
             if (FD_ISSET(talkToSelfFiledes[0], &fdset)) {
                char buf[2];
@@ -1289,23 +1303,41 @@ int GetAnXEvent(pXEvent)
                         TOOL_NAME),
                   fprintf(stderr, "%s\n", gszMsgBox);
                } else {
-                  SendCommandToSelf(CMDID_DATA_IN_MBUFF, 0);
+                  if (*buf == 'a') {
+                     SendCommandToSelf(CMDID_DATA_IN_MBUFF, 0);
+                  } else if (*buf == 'c') {
+                     /*
+                      * Get current tgwb state and establish
+                      *         a TCP conection to send the data.
+                      */
+                     HandleNewUserRequest();
+                  } else {
+                     sprintf(gszMsgBox,
+                           TgLoadString(STID_READ_FROM_SELF_PIPE_FAIL), 1,
+                           TOOL_NAME),
+                     fprintf(stderr, "%s\n", gszMsgBox);
+                  }
                }
-               return FALSE;
+               rc = FALSE;
             } else if (FD_ISSET(select_width-1, &fdset)) {
                XNextEvent(mainDisplay, pXEvent);
             } else {
-               return FALSE;
+               rc = FALSE;
             }
          } else {
             sprintf(gszMsgBox, TgLoadString(STID_FUNC_INVALID_RC_FOR_SELECT),
                   "GetAnXEvent()", status);
             fprintf(stderr, "%s\n", gszMsgBox);
-            return FALSE;
+            rc = FALSE;
          }
       }
    }
    gstWBInfo.BlockRemoteCmdDepth++;
+#ifdef DEBUG0
+   fprintf(stderr,"BlockRemoteCmdDepth (GetAnXEvent): %d\n",
+         gstWBInfo.BlockRemoteCmdDepth);
+#endif /* DEBUG0 */
+   if (!rc) return FALSE;
 #endif /* _TGIF_WB2 */
 
 #if !defined(_TGIF_WB) && !defined(_TGIF_WB2)
@@ -1341,9 +1373,7 @@ int TryProcessAnXEvent(pnNeedToCheckAutoExec)
       return 0;
    }
 
-   if (input.type == KeyRelease) {
-      return 0;
-   } else if (input.type == FocusIn) {
+   if (input.type == FocusIn) {
       if (canvasFontDoubleByte && curChoice == DRAWTEXT && textCursorShown) {
          tgIMFocusIn(mainDisplay, mainWindow);
       }
@@ -1351,6 +1381,8 @@ int TryProcessAnXEvent(pnNeedToCheckAutoExec)
       if (canvasFontDoubleByte && curChoice == DRAWTEXT && textCursorShown) {
          tgIMFocusOut(mainDisplay, mainWindow);
       }
+   } else if (input.type == KeyRelease) {
+      return 0;
    } else if (input.type == KeyPress) {
       rc = ShortHand(&input);
       switch (rc) {
@@ -1369,7 +1401,23 @@ int TryProcessAnXEvent(pnNeedToCheckAutoExec)
          return rc;
       }
    } else if (input.xany.window == drawWindow) {
-      if ((rc=DrawingEventHandler(&input)) != INVALID) {
+#ifdef _TGIF_WB2
+      if (input.type == ButtonPress) {
+         if (gstWBInfo.do_whiteboard) {
+            gstWBInfo.BlockRemoteCmdDepth++;
+         }
+      }
+#endif /* _TGIF_WB2 */
+      rc = DrawingEventHandler(&input);
+#ifdef _TGIF_WB2
+      if (input.type == ButtonPress) {
+         if (gstWBInfo.do_whiteboard) {
+            gstWBInfo.BlockRemoteCmdDepth--;
+            TryHandleWBInputData();
+         }
+      }
+#endif /* _TGIF_WB2 */
+      if (rc != INVALID) {
          return rc;
       }
    } else if (input.xany.window == mainWindow) {
@@ -1500,7 +1548,7 @@ void MainLoop(Op, FileName, FuncStr, Str1, Menu1, Str2, Menu2, Str3, Menu3)
       GetTgifVersionAndPatchLevel(szMsg1, sizeof(szMsg1));
       sprintf(szMsg2, "%s (%s)", copyrightString, authorEmailString);
       TwoLineMsg(szMsg1, szMsg2);
-      if (!cmdLineDumpURL) {
+      if (cmdLineVersion) {
          fprintf(stderr, "%s\n", szMsg1);
          fprintf(stderr, "%s\n", szMsg2);
       }
@@ -1622,6 +1670,10 @@ void UrlDump(pszUrl)
          cmdLineDumpURL = FALSE;
          debugHttp = saved_http_debug;
          InitHtml();
+      } else {
+         if (cmdLineOpenDisplay) {
+            JustInit(NULL, NULL);
+         }
       }
       DownloadRemoteFile(pszUrl, &content_type, &page_spec,
             &is_html, tmp_fname, NULL, 0);
@@ -1725,7 +1777,7 @@ void Animate(TypeStr, PolyId, SpeedStr, ColorStr, ReturnStr)
    if (strcmp(TypeStr, "waitclick") == 0) {
       Msg(TgLoadString(STID_LEFT_STEP_MID_RUN_RIGHT_STOP));
       if (!clicked) {
-         while(TRUE) {
+         while (TRUE) {
             if (XPending(mainDisplay) != 0) {
                XNextEvent(mainDisplay, &input);
                if (input.type == ButtonPress) {
