@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/menuinfo.c,v 4.109 2001/10/15 15:23:56 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/menuinfo.c,v 4.111 2002/03/21 07:44:55 william Exp $
  */
 
 #define _INCLUDE_FROM_MENUINFO_C_
@@ -1125,6 +1125,8 @@ static TgMenuItemInfo showHideMenuItemInfo[] = {
      CMDID_TOGGLESHOWCHOICEBAR },
    { N_("Show Status"), NULL, N_("Show status window"), NULL,
      CMDID_TOGGLESHOWSTATUS },
+   { N_("Show Mode"), NULL, N_("Show mode window"), NULL,
+     CMDID_TOGGLESHOWMODE },
    { NULL, NULL, NULL, NULL, INVALID }
 };
 static TgMenuInfo showHideMenuInfo={ TGMUTYPE_TEXT, showHideMenuItemInfo,
