@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/move.c,v 4.12 2001/08/06 21:39:07 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/move.c,v 4.20 2002/03/07 18:11:33 william Exp $
  */
 
 #define _INCLUDE_FROM_MOVE_C_
@@ -1195,7 +1195,7 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
    int sel_ltx=0, sel_lty=0, sel_rbx=0, sel_rby=0;
    int ruler_ltx=0, ruler_lty=0, ruler_rbx=0, ruler_rby=0;
    int moving=TRUE, dx=0, dy=0, grid_x=OrigX, grid_y=OrigY;
-   int can_move_sub_obj=FALSE, move_sub_obj=FALSE;
+   int can_move_sub_obj=FALSE, move_sub_obj=FALSE, no_no_lock_sel=FALSE;
    char buf[80], x_buf[80], y_buf[80];
    XEvent ev;
    Time down_click_time=(Time)0;
@@ -1205,8 +1205,7 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
       down_click_time = down_button_ev->time;
    }
    if (numObjSelected == numObjLocked || ObjPtr->locked) {
-      MsgBox(TgLoadString(STID_LOCKED_OBJS_CANT_BE_MOVED), TOOL_NAME, INFO_MB);
-      return;
+      no_no_lock_sel = TRUE;
    }
    XFlush(mainDisplay);
    XSync(mainDisplay, False);
@@ -1219,16 +1218,23 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
       can_move_sub_obj = TRUE;
       SetStringStatus(TgLoadString(STID_HINT_CTL_MOVE_ATTR_ONLY));
    }
-   sel_ltx = OFFSET_X(selNoLockLtX) - 1; sel_lty = OFFSET_Y(selNoLockLtY) - 1;
-   sel_rbx = OFFSET_X(selNoLockRbX) + 1; sel_rby = OFFSET_Y(selNoLockRbY) + 1;
-
+   if (!move_sub_obj && !no_no_lock_sel) {
+      sel_ltx = OFFSET_X(selNoLockLtX)-1; sel_lty = OFFSET_Y(selNoLockLtY)-1;
+      sel_rbx = OFFSET_X(selNoLockRbX)+1; sel_rby = OFFSET_Y(selNoLockRbY)+1;
+   }
    ruler_ltx = OFFSET_X(selNoLockObjLtX); ruler_lty = OFFSET_Y(selNoLockObjLtY);
    ruler_rbx = OFFSET_X(selNoLockObjRbX); ruler_rby = OFFSET_Y(selNoLockObjRbY);
 
-   SelBox(drawWindow, revDefaultGC, sel_ltx, sel_lty, sel_rbx, sel_rby);
+   if (!move_sub_obj && !no_no_lock_sel) {
+      SelBox(drawWindow, revDefaultGC, sel_ltx, sel_lty, sel_rbx, sel_rby);
+   }
    PixelToMeasurementUnit(x_buf, 0);
    PixelToMeasurementUnit(y_buf, 0);
-   sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+   if (VerboseMeasureTooltip()) {
+      sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+   } else {
+      sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+   }
    StartShowMeasureCursor(OrigX, OrigY, buf, TRUE);
    BeginIntervalRulers(ruler_ltx, ruler_lty, ruler_rbx, ruler_rby);
 
@@ -1260,9 +1266,13 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
          EndIntervalRulers(grid_x, grid_y);
          PixelToMeasurementUnit(x_buf, ABS_SIZE(dx));
          PixelToMeasurementUnit(y_buf, ABS_SIZE(dy));
-         sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         if (VerboseMeasureTooltip()) {
+            sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+         } else {
+            sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         }
          EndShowMeasureCursor(grid_x, grid_y, buf, TRUE);
-         if (!move_sub_obj) {
+         if (!move_sub_obj && !no_no_lock_sel) {
             SelBox(drawWindow, revDefaultGC, sel_ltx+dx, sel_lty+dy, sel_rbx+dx,
                   sel_rby+dy);
          }
@@ -1284,7 +1294,11 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
 
          PixelToMeasurementUnit(x_buf, ABS_SIZE(dx));
          PixelToMeasurementUnit(y_buf, ABS_SIZE(dy));
-         sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         if (VerboseMeasureTooltip()) {
+            sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+         } else {
+            sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         }
          ShowMeasureCursor(grid_x, grid_y, buf, TRUE);
          if (input.type == KeyPress || input.type == KeyRelease) {
             x = grid_x;
@@ -1308,22 +1322,49 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
 
          /* erase */
          DrawInnerRubberObj(ObjPtr, &rubber_info, dx, dy);
-         if (!saved_move_sub_obj) {
+         if (!saved_move_sub_obj && !no_no_lock_sel) {
             SelBox(drawWindow, revDefaultGC, sel_ltx+dx, sel_lty+dy, sel_rbx+dx,
                   sel_rby+dy);
          }
          dx = grid_x - OrigX;
          dy = grid_y - OrigY;
 
-         DrawIntervalRulers(ruler_ltx+dx, ruler_lty+dy, ruler_rbx+dx,
-               ruler_rby+dy);
-         if (!move_sub_obj) {
-            SelBox(drawWindow, revDefaultGC, sel_ltx+dx, sel_lty+dy, sel_rbx+dx,
-                  sel_rby+dy);
+         if ((dx != 0 || dy != 0) &&
+               (numObjSelected == numObjLocked || ObjPtr->locked)) {
+            XUngrabPointer(mainDisplay, CurrentTime);
+            XSync(mainDisplay, False);
+
+            EndIntervalRulers(grid_x, grid_y);
+            PixelToMeasurementUnit(x_buf, ABS_SIZE(dx));
+            PixelToMeasurementUnit(y_buf, ABS_SIZE(dy));
+            if (VerboseMeasureTooltip()) {
+               sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+            } else {
+               sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+            }
+            ShowMeasureCursor(grid_x, grid_y, buf, TRUE);
+            EndShowMeasureCursor(grid_x, grid_y, buf, TRUE);
+            if (!move_sub_obj && !no_no_lock_sel) {
+               SelBox(drawWindow, revDefaultGC, sel_ltx+dx, sel_lty+dy,
+                     sel_rbx+dx, sel_rby+dy);
+            }
+            MsgBox(TgLoadString(STID_LOCKED_OBJS_CANT_BE_MOVED), TOOL_NAME,
+                  INFO_MB);
+            return;
          }
          PixelToMeasurementUnit(x_buf, ABS_SIZE(dx));
          PixelToMeasurementUnit(y_buf, ABS_SIZE(dy));
-         sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         if (VerboseMeasureTooltip()) {
+            sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+         } else {
+            sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         }
+         DrawIntervalRulers(ruler_ltx+dx, ruler_lty+dy, ruler_rbx+dx,
+               ruler_rby+dy, buf);
+         if (!move_sub_obj && !no_no_lock_sel) {
+            SelBox(drawWindow, revDefaultGC, sel_ltx+dx, sel_lty+dy, sel_rbx+dx,
+                  sel_rby+dy);
+         }
          ShowMeasureCursor(grid_x, grid_y, buf, TRUE);
 
          UpdateInnerRubberObj(ObjPtr, &rubber_info, dx, dy);
@@ -1335,6 +1376,11 @@ void MoveSel(OrigX, OrigY, ObjPtr, down_button_ev)
    FreeRubberInfo(ObjPtr, &rubber_info);
 
    if (dx != 0 || dy != 0) {
+      if (numObjSelected == numObjLocked || ObjPtr->locked) {
+         MsgBox(TgLoadString(STID_LOCKED_OBJS_CANT_BE_MOVED), TOOL_NAME,
+               INFO_MB);
+         return;
+      }
       HighLightReverse();
       dx = ABS_SIZE(dx);
       dy = ABS_SIZE(dy);
@@ -1782,18 +1828,55 @@ void MarkVs(Dir, Dx, Dy)
    }
 }
 
+static
+void GetSelectedVsBBox(pBBox)
+   struct BBRec *pBBox;
+{
+   int found=FALSE, ltx=0, lty=0, rbx=0, rby=0;
+   struct VSelRec *vsel_ptr=NULL;
+
+   vsel_ptr = botVSel;
+   while (vsel_ptr != NULL) {
+      int i=0;
+
+      for (i=0; i < vsel_ptr->n; i++) {
+         if (!(vsel_ptr->obj->type==OBJ_POLYGON &&
+               vsel_ptr->obj->detail.g->n-1==vsel_ptr->v_index[i])) {
+            int x=OFFSET_X(vsel_ptr->x[i]);
+            int y=OFFSET_Y(vsel_ptr->y[i]);
+
+            if (found) {
+               if (x < ltx) ltx = x;
+               if (x > rbx) rbx = x;
+               if (y < lty) lty = y;
+               if (y > rby) rby = y;
+            } else {
+               found = TRUE;
+               ltx = rbx = x;
+               lty = rby = y;
+            }
+         }
+      }
+      vsel_ptr = vsel_ptr->prev;
+   }
+   if (found) {
+      pBBox->ltx = ltx; pBBox->lty = lty; pBBox->rbx = rbx; pBBox->rby = rby;
+   }
+}
+
 void MoveSelVs(OrigX, OrigY)
    int OrigX, OrigY;
 {
-   int x, y, i;
-   struct ObjRec *obj_ptr;
-   struct VSelRec *vsel_ptr;
-   struct PolyRec *poly_ptr;
-   struct PolygonRec *polygon_ptr;
-   IntPoint *pv;
-   int moving = TRUE, dx, dy, num_pts, curved;
-   int grid_x=OrigX, grid_y=OrigY;
+   int x=0, y=0, i=0;
+   struct ObjRec *obj_ptr=NULL;
+   struct VSelRec *vsel_ptr=NULL;
+   struct PolyRec *poly_ptr=NULL;
+   struct PolygonRec *polygon_ptr=NULL;
+   IntPoint *pv=NULL;
+   int moving=TRUE, dx=0, dy=0, num_pts=0, curved=FALSE;
+   int grid_x=OrigX, grid_y=OrigY, abs_dx_from_orig=0, abs_dy_from_orig=0;
    int saved_grid_x=OrigX, saved_grid_y=OrigY;
+   struct BBRec ruler_bbox;
    char buf[80], x_buf[80], y_buf[80];
    XEvent ev;
 
@@ -1810,17 +1893,27 @@ void MoveSelVs(OrigX, OrigY)
    HighLightVs(FORWARD);
    MarkVs(FORWARD, 0, 0);
 
+   memset(&ruler_bbox, 0, sizeof(struct BBRec));
+   GetSelectedVsBBox(&ruler_bbox);
+
    PixelToMeasurementUnit(x_buf, 0);
    PixelToMeasurementUnit(y_buf, 0);
    sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+   if (VerboseMeasureTooltip()) {
+      sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+   } else {
+      sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+   }
    StartShowMeasureCursor(grid_x, grid_y, buf, TRUE);
+   BeginIntervalRulers(ruler_bbox.ltx, ruler_bbox.lty, ruler_bbox.rbx,
+         ruler_bbox.rby);
 
    if (!debugNoPointerGrab) {
       XGrabPointer(mainDisplay, drawWindow, FALSE,
             PointerMotionMask | ButtonReleaseMask,
             GrabModeAsync, GrabModeAsync, None, moveCursor, CurrentTime);
    }
-   while(moving) {
+   while (moving) {
       XEvent input;
 
       XNextEvent(mainDisplay, &input);
@@ -1830,9 +1923,15 @@ void MoveSelVs(OrigX, OrigY)
       } else if (input.type == ButtonRelease) {
          XUngrabPointer(mainDisplay, CurrentTime);
          XSync(mainDisplay, False);
+
+         EndIntervalRulers(grid_x, grid_y);
          PixelToMeasurementUnit(x_buf, ABS_SIZE(grid_x-OrigX));
          PixelToMeasurementUnit(y_buf, ABS_SIZE(grid_y-OrigY));
-         sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         if (VerboseMeasureTooltip()) {
+            sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+         } else {
+            sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         }
          EndShowMeasureCursor(grid_x, grid_y, buf, TRUE);
          MarkRulers(grid_x, grid_y);
          moving = FALSE;
@@ -1855,7 +1954,11 @@ void MoveSelVs(OrigX, OrigY)
             input.type == KeyRelease) {
          PixelToMeasurementUnit(x_buf, ABS_SIZE(grid_x-OrigX));
          PixelToMeasurementUnit(y_buf, ABS_SIZE(grid_y-OrigY));
-         sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         if (VerboseMeasureTooltip()) {
+            sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+         } else {
+            sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         }
          ShowMeasureCursor(grid_x, grid_y, buf, TRUE);
          MarkVs(REVERSE, grid_x-OrigX, grid_y-OrigY);
          HighLightVs(REVERSE);
@@ -1884,8 +1987,7 @@ void MoveSelVs(OrigX, OrigY)
          saved_grid_x = grid_x;
          saved_grid_y = grid_y;
 
-         MarkRulers(grid_x, grid_y);
-         for (vsel_ptr=botVSel, obj_ptr = tmpBotObj; vsel_ptr != NULL;
+         for (vsel_ptr=botVSel, obj_ptr=tmpBotObj; vsel_ptr != NULL;
                vsel_ptr=vsel_ptr->prev, obj_ptr=obj_ptr->prev) {
             switch (obj_ptr->type) {
             case OBJ_POLY:
@@ -1958,10 +2060,19 @@ void MoveSelVs(OrigX, OrigY)
             }
          }
          HighLightVs(FORWARD);
+         abs_dx_from_orig = ABS_SIZE(grid_x-OrigX);
+         abs_dy_from_orig = ABS_SIZE(grid_y-OrigY);
          MarkVs(FORWARD, grid_x-OrigX, grid_y-OrigY);
-         PixelToMeasurementUnit(x_buf, ABS_SIZE(grid_x-OrigX));
-         PixelToMeasurementUnit(y_buf, ABS_SIZE(grid_y-OrigY));
-         sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         PixelToMeasurementUnit(x_buf, abs_dx_from_orig);
+         PixelToMeasurementUnit(y_buf, abs_dy_from_orig);
+         if (VerboseMeasureTooltip()) {
+            sprintf(buf, "dx=%s dy=%s", x_buf, y_buf);
+         } else {
+            sprintf(buf, "dx=%s\ndy=%s", x_buf, y_buf);
+         }
+         DrawIntervalRulers(ruler_bbox.ltx+abs_dx_from_orig,
+               ruler_bbox.lty+abs_dy_from_orig, ruler_bbox.rbx+abs_dx_from_orig,
+               ruler_bbox.rby+abs_dy_from_orig, buf);
          ShowMeasureCursor(grid_x, grid_y, buf, TRUE);
          while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
       }
