@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/msg.c,v 4.57 2001/10/15 20:54:10 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/msg.c,v 4.62 2002/03/10 23:28:53 william Exp $
  */
 
 #define _INCLUDE_FROM_MSG_C_
@@ -1397,6 +1397,7 @@ void Usage(tool_name)
    fprintf(stderr, "\t[-dbim {xcin|chinput|xim|kinput2}] \\\n");
    fprintf(stderr, "\t[-usexlib] \\\n");
    fprintf(stderr, "\t[-listdontreencode] \\\n");
+   fprintf(stderr, "\t[-version] \\\n");
    fprintf(stderr, "\t[{<file>[.%s] | -merge <file1>[.%s] <file2>[.%s] ...}]\n",
          OBJ_FILE_EXT, OBJ_FILE_EXT, OBJ_FILE_EXT);
    fprintf(stderr, "or:\n");
@@ -1416,12 +1417,14 @@ void Usage(tool_name)
    fprintf(stderr,
          "\t[-dontreencode=\"<%s>:<%s>:...\" | -listdontreencode] \\\n",
          "fontfamily", "fontfamily");
+   fprintf(stderr, "\t[-version] \\\n");
+   fprintf(stderr, "\t[-pdfspd | -pdfspd=true | -pdfspd=false] \\\n");
    fprintf(stderr, "\t[-producedby=\"<string>\"] \\\n");
    fprintf(stderr, "\t[-page <number>] \\\n");
    fprintf(stderr, "\t[-print_cmd \"<command>\"] \\\n");
    fprintf(stderr, "\t[-one_file_per_page] \\\n");
    fprintf(stderr, "\t[-pepsc] \\\n");
-   fprintf(stderr, "\t[-nolandpdfspd] \\\n");
+   fprintf(stderr, "\t[-pdfspd | -pdfspd=true | -pdfspd=false] \\\n");
    fprintf(stderr, "\t[-dontcondense | -condensed] \\\n");
    fprintf(stderr, "\t[-a4] \\\n");
    fprintf(stderr, "\t[-quiet] \\\n");
@@ -1440,7 +1443,7 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
    char *argv[];
 {
    char *c_ptr=NULL;
-   int saved_argc=argc, show_copyright=TRUE;
+   int saved_argc=argc, show_copyright=FALSE;
    char **saved_argv=argv;
 
    *cmdLineTmpFileModeStr = '\0';
@@ -1448,18 +1451,8 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
    *outputDir = '\0';
    for (argc--, argv++; argc > 0; argc--, argv++) {
       if (**argv == '-') {
-         if (strcmp(*argv, "-raw") == 0) {
-            show_copyright = FALSE;
-         } else if (strcmp(*argv, "-raw+h") == 0) {
-            show_copyright = FALSE;
-         } else if (strcmp(*argv, "-raw+headeronly") == 0) {
-            show_copyright = FALSE;
-         } else if (strcmp(*argv, "-stdout") == 0) {
-            show_copyright = FALSE;
-         } else if (strcmp(*argv, "-parse_html") == 0) {
-            show_copyright = FALSE;
-         } else if (strcmp(*argv, "-quiet") == 0) {
-            show_copyright = FALSE;
+         if (strcmp(*argv, "-version") == 0) {
+            show_copyright = TRUE;
          }
       }
    }
@@ -1469,7 +1462,7 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
       char buf[MAXSTRING];
 
       GetTgifVersionAndPatchLevel(buf, sizeof(buf));
-      fprintf(stderr, "%s", buf);
+      fprintf(stderr, "%s\n", buf);
       fprintf(stderr, "%s (%s)\n\n", copyrightString, authorEmailString);
       fflush(stderr);
    }
@@ -1616,7 +1609,26 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
          } else if (strcmp(*argv, "-pepsc") == 0) {
             stripEPSComments = FALSE;
          } else if (strcmp(*argv, "-nolandpdfspd") == 0) {
-            cmdLineNoLandscapePdfSetPageDevice = TRUE;
+            cmdLinePdfSetPageDevice = FALSE;
+            fprintf(stderr, TgLoadString(STID_OBSOLETE_CMDLINE_ASSUME),
+                  "-nolandpdfspd", "-pdfspd=false");
+            fprintf(stderr, "\n");
+         } else if (strcmp(*argv, "-pdfspd") == 0) {
+            cmdLinePdfSetPageDevice = TRUE;
+         } else if (strncmp(*argv, "-pdfspd=", 8) == 0) {
+            char tmp_str[80];
+
+            UtilStrCpyN(tmp_str, sizeof(tmp_str), &(*argv)[8]);
+            UtilTrimBlanks(tmp_str);
+            if (UtilStrICmp(tmp_str, "true") == 0) {
+               cmdLinePdfSetPageDevice = TRUE;
+            } else if (UtilStrICmp(tmp_str, "false") == 0) {
+               cmdLinePdfSetPageDevice = FALSE;
+            } else {
+               fprintf(stderr, TgLoadString(STID_BAD_CMDLINE_OPT_IGNORED),
+                     "-pdfspd", tmp_str);
+               fprintf(stderr, "\n");
+            }
          } else if (strcmp(*argv, "-dontcondense") == 0) {
             SetCmdLineDontCondense();
          } else if (strcmp(*argv, "-condensed") == 0) {
@@ -1686,8 +1698,8 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
             UtilTrimBlanks(tmp_str);
             if (!ParsePsAdobeString(tmp_str, &usePsAdobeString, adobeString,
                   epsfString)) {
-               fprintf(stderr, TgLoadString(STID_INVALID_XDEF_USE_ALT_STR),
-                     TOOL_NAME, "UsePsAdobeString", tmp_str, "false");
+               fprintf(stderr, TgLoadString(STID_BAD_CMDLINE_OPT_USE_ALT_STR),
+                     "-adobe", tmp_str, "false");
                fprintf(stderr, "\n");
                usePsAdobeString = FALSE;
                *adobeString = *epsfString = '\0';
@@ -1696,6 +1708,8 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
 #ifdef _DONT_REENCODE
             fprintf(stderr, "-D_DONT_REENCODE=\"%s\"\n", _DONT_REENCODE);
 #endif /* _DONT_REENCODE */
+         } else if (strcmp(*argv, "-version") == 0) {
+            cmdLineVersion = TRUE;
          } else if (strncmp(*argv, "-dontreencode=", 14) == 0) {
             strcpy(cmdLineDontReencode, &(*argv)[14]);
             UtilTrimBlanks(cmdLineDontReencode);
@@ -1904,10 +1918,28 @@ int ProcessTgifOptions(argc, argv, file_name, name_sz)
 #ifdef _DONT_REENCODE
          fprintf(stderr, "-D_DONT_REENCODE=\"%s\"\n", _DONT_REENCODE);
 #endif /* _DONT_REENCODE */
-      } else if (*argv[i] == '=') {
+      } else if (strcmp(argv[i], "-version") == 0) {
+         cmdLineVersion = TRUE;
+      } else if (strcmp(argv[i], "-pdfspd") == 0) {
+         cmdLinePdfSetPageDevice = TRUE;
+      } else if (strncmp(argv[i], "-pdfspd=", 8) == 0) {
+         char tmp_str[80];
+
+         UtilStrCpyN(tmp_str, sizeof(tmp_str), &(argv[i])[8]);
+         UtilTrimBlanks(tmp_str);
+         if (UtilStrICmp(tmp_str, "true") == 0) {
+            cmdLinePdfSetPageDevice = TRUE;
+         } else if (UtilStrICmp(tmp_str, "false") == 0) {
+            cmdLinePdfSetPageDevice = FALSE;
+         } else {
+            fprintf(stderr, TgLoadString(STID_BAD_CMDLINE_OPT_IGNORED),
+                  "-pdfspd", tmp_str);
+            fprintf(stderr, "\n");
+         }
+      } else if (argv[i][i] == '=') {
          strcpy(geometrySpec, argv[i]);
          geometrySpecified = TRUE;
-      } else if (*argv[i] != '-') {
+      } else if (argv[i][i] != '-') {
          if (cmdLineMerge) {
             int j=0;
 
