@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/names.c,v 4.48 2001/08/06 21:39:08 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/names.c,v 4.50 2002/01/05 02:48:03 william Exp $
  */
 
 #define _INCLUDE_FROM_NAMES_C_
@@ -677,7 +677,11 @@ void InitDomain()
          ParseSymPath(c_ptr);
       }
    } else {
-      ParseSymPath(".");
+      char buf[MAXPATHLENGTH];
+
+      strcpy(buf, ".:");
+      UtilStrCpyN(&buf[2], sizeof(buf)-2, TGIF_PATH);
+      ParseSymPath(buf);
    }
    if (need_to_copy_domain_into_ini) {
       CopyDomainInfoToIni();
