@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/navigate.c,v 4.37 2001/09/04 14:36:37 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/navigate.c,v 4.40 2002/03/24 21:18:32 william Exp $
  */
 
 #define _INCLUDE_FROM_NAVIGATE_C_
@@ -102,6 +102,8 @@ static struct URLCacheRec *firstURLCache=NULL, *lastURLCache=NULL;
 static int maxURLCache=(-1), curURLCache=0;
 
 static int lineWidthIndexInSlideShow=4;
+static int makeUnsavableInSlideShow=FALSE;
+
 
 int ParseXYSpec(spec, pnx, pny)
    char *spec;
@@ -348,6 +350,11 @@ void InitNavigate()
       if (slideShowBorderColor == NULL) FailAllocMessage();
       slideShowInfoValid = TRUE;
    }
+   makeUnsavableInSlideShow = FALSE;
+   if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"MakeUnsavableInSlideShow")) !=
+         NULL && UtilStrICmp(c_ptr, "true") == 0) {
+      makeUnsavableInSlideShow = TRUE;
+   }
 }
 
 static
@@ -1342,7 +1349,7 @@ void ToggleSlideShow()
       if (pageLayoutMode == PAGE_TILE) {
          switch (MsgBox(TgLoadString(STID_CANT_SLIDESHOW_IN_TILED_PAGE),
                TOOL_NAME, YNC_MB)) {
-         case MB_ID_YES: break;
+         case MB_ID_YES: SetUnSavableFile(TRUE); break;
          case MB_ID_NO: return;
          case MB_ID_CANCEL: return;
          }
@@ -1359,18 +1366,22 @@ void ToggleSlideShow()
             case MB_ID_CANCEL: return;
             }
          }
-         if (!IsFiletUnSavable() && NeedToFixPageNumbersForSlideShow()) {
-            sprintf(gszMsgBox,
-                  TgLoadString(STID_Q_PAGE_NUM_MOD_IN_SLIDE_YNC), TOOL_NAME);
-            switch (MsgBox(gszMsgBox, TOOL_NAME, YNC_MB)) {
-            case MB_ID_YES: SetUnSavableFile(TRUE); break;
-            case MB_ID_NO: return;
-            case MB_ID_CANCEL: return;
+         if (!IsFiletUnSavable() && (makeUnsavableInSlideShow ||
+               NeedToFixPageNumbersForSlideShow())) {
+            if (!makeUnsavableInSlideShow) {
+               sprintf(gszMsgBox,
+                     TgLoadString(STID_Q_PAGE_NUM_MOD_IN_SLIDE_YNC), TOOL_NAME);
+               switch (MsgBox(gszMsgBox, TOOL_NAME, YNC_MB)) {
+               case MB_ID_YES: break;
+               case MB_ID_NO: return;
+               case MB_ID_CANCEL: return;
+               }
             }
+            SetUnSavableFile(TRUE);
          }
-         MakeQuiescent();
-         need_to_restore_cur_choice = TRUE;
       }
+      MakeQuiescent();
+      need_to_restore_cur_choice = TRUE;
    }
    inSlideShow = !inSlideShow;
 
