@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/remote.c,v 4.37 2001/08/06 21:39:12 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/remote.c,v 4.41 2002/02/22 22:55:16 william Exp $
  */
 
 #define _INCLUDE_FROM_REMOTE_C_
@@ -163,8 +163,9 @@ void InitUserAgentName()
    if (!gnUserAgentInitialized) {
       gnUserAgentInitialized = TRUE;
       *gszUserAgentName = '\0';
-      if (!PRTGIF && (c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
-            "UserAgentName")) != NULL) {
+      if (!(PRTGIF && !cmdLineOpenDisplay) &&
+            (c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "UserAgentName")) !=
+            NULL) {
          strcpy(gszUserAgentName, c_ptr);
          UtilTrimBlanks(gszUserAgentName);
       }
@@ -557,7 +558,11 @@ char *WriteRemoteFileIntoTemp(psz_buf, buf_sz, psz_ext)
       FailAllocMessage();
       return NULL;
    }
-   MkTempFile(tmp_fname, (strlen(tmpDir)+19)*sizeof(char), tmpDir, TOOL_NAME);
+   if (MkTempFile(tmp_fname, (strlen(tmpDir)+19)*sizeof(char), tmpDir,
+         TOOL_NAME) == NULL) {
+      free(tmp_fname);
+      return NULL;
+   }
    if (psz_ext != NULL) strcat(tmp_fname, psz_ext);
    unlink(tmp_fname);
    if ((fd=open(tmp_fname, O_WRONLY|O_CREAT|O_TRUNC)) == (-1)) {
@@ -809,7 +814,7 @@ int LoadHttpIntoMem(url, host, port, path, ppsz_buf, ppsz_content_type,
                }
             }
             if (*ppsz_buf != NULL && debugHttp > 0) {
-               if (debugHttp == 99) {
+               if ((debugHttp % 100) == 99) {
                   /*
                    * Because of the way HttpExtractText() is coded,
                    * if *ppsz_buf != NULL, (*ppsz_buf)[*pn_buf_sz] is '\0'
@@ -1096,20 +1101,39 @@ int LoadAuthenticatedFileInMem(url, host, port, ppsz_buf, ppsz_content_type,
       gnAuthCount--;
       ResetAuthorization();
    } else {
-      char user_name[MAXSTRING+1], password[MAXSTRING+1];
+      char *psz=NULL, user_name[MAXSTRING+1], password[MAXSTRING+1];
 
       *user_name = *password = '\0';
       sprintf(gszMsgBox, TgLoadString(STID_AUTHEN_REQ_FOR_REALM),
             "HTTP", realm);
       ShowRemoteStatus(gszMsgBox);
       sprintf(gszMsgBox, TgLoadString(STID_ENTER_USERNAME_FOR_REALM), realm);
-      Dialog(gszMsgBox, TgLoadCachedString(CSTID_DLG_ACCEPT_CANCEL), user_name);
+      if (mainDisplay == NULL) {
+         fprintf(stdout, "%s ", gszMsgBox);
+         psz = UtilGetALine(stdin);
+         if (psz != NULL) {
+            UtilStrCpyN(user_name, sizeof(user_name), psz);
+            UtilFree(psz);
+         }
+      } else {
+         Dialog(gszMsgBox, TgLoadCachedString(CSTID_DLG_ACCEPT_CANCEL),
+               user_name);
+      }
       UtilTrimBlanks(user_name);
       if (*user_name != '\0') {
          *password = '\0';
          sprintf(gszMsgBox, TgLoadString(STID_ENTER_PASSWORD_FOR_REALM), realm);
          doPassword = TRUE;
-         Dialog(gszMsgBox, NULL, password);
+         if (mainDisplay == NULL) {
+            fprintf(stdout, "%s ", gszMsgBox);
+            psz = UtilGetALine(stdin);
+            if (psz != NULL) {
+               UtilStrCpyN(password, sizeof(password), psz);
+               UtilFree(psz);
+            }
+         } else {
+            Dialog(gszMsgBox, NULL, password);
+         }
          doPassword = FALSE;
       }
       if (*user_name != '\0' && *password != '\0') {
