@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/setup.c,v 4.70 2001/10/14 00:19:58 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/setup.c,v 4.72 2002/03/21 07:44:55 william Exp $
  */
 
 #define _INCLUDE_FROM_SETUP_C_
@@ -1240,6 +1240,11 @@ void Setup()
       }
    }
    noModeWindow = FALSE;
+   if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"NoModeWindow")) != NULL) {
+      if (UtilStrICmp("true", c_ptr) == 0) {
+         noModeWindow = TRUE;
+      }
+   }
    noChatWindow = TRUE;
 
    scrollBarW = baseScrollBarW = SCROLLBAR_W;
