@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/shape.c,v 4.16 2001/08/06 21:39:13 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/shape.c,v 4.18 2002/03/06 07:23:39 william Exp $
  */
 
 #define _INCLUDE_FROM_SHAPE_C_
@@ -1055,7 +1055,7 @@ void ContinueCreateShape(orig_x, orig_y)
          }
          DoCursor(grid_x, grid_y, grid_x-orig_x, grid_y-orig_y, MOTION_SHOW);
          HighLightCreateShape(grid_x, grid_y, GENERATE, &need_to_draw);
-         DrawIntervalRulers(orig_x, orig_y, grid_x, grid_y);
+         DrawIntervalRulers(orig_x, orig_y, grid_x, grid_y, NULL);
          while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
          break;
       case KeyPress:
