@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/special.c,v 4.56 2001/08/06 21:39:14 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/special.c,v 4.58 2002/01/05 02:48:06 william Exp $
  */
 
 #define _INCLUDE_FROM_SPECIAL_C_
@@ -452,8 +452,12 @@ void Instantiate()
 
    MakeQuiescent();
 
-   sprintf(msg, TgLoadString(STID_SEL_A_SYM_TO_INSTAN_IN_DOMAIN),
-         curDomainName);
+   if (*curDomainName == '\0') {
+      strcpy(msg, TgLoadString(STID_SEL_A_SYM_TO_INSTAN_IN_NONE));
+   } else {
+      sprintf(msg, TgLoadString(STID_SEL_A_SYM_TO_INSTAN_IN_DOMAIN),
+            curDomainName);
+   }
    if (SelectFromLibrary(msg, SYM_FILE_EXT, sym_name, path_name) == INVALID) {
       return;
    }
