@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/stream.c,v 4.19 2001/08/11 21:56:20 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/stream.c,v 4.21 2002/02/22 22:55:45 william Exp $
  */
 
 #define _INCLUDE_FROM_STREAM_C_
@@ -357,7 +357,8 @@ int GetContentLength(buf)
          gnHeaderLen = gnStartIndex = ((&c_ptr[inc]) - buf);
          if (good_content_type && gpszBoundary != NULL) {
             gnMultipartReplace = TRUE;
-            if (debugHttp == 99 && cmdLineDumpURL && cmdLineDumpURLWithHeader) {
+            if ((debugHttp % 100) == 99 && cmdLineDumpURL &&
+                  cmdLineDumpURLWithHeader) {
                fprintf(stdout, "%s", buf);
             }
          } else {
