@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2001, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2002, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/wb.c,v 4.71 2001/10/16 20:22:01 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/wb.c,v 4.82 2002/03/28 00:16:28 william Exp $
  */
 
 #define _INCLUDE_FROM_WB_C_
@@ -68,6 +68,7 @@
 #include "strtbl.e"
 #include "tcp.e"
 #include "util.e"
+#include "version.e"
 #include "wb.e"
 #include "wb_buff.e"
 #include "wb_seg.e"
@@ -157,9 +158,12 @@ int CreateWBListenSocket()
 {
    gstWBInfo.listening = TRUE;
 
-   sprintf(gstWBInfo.listen_fname, "%sTgifLXXXXXX", TMP_DIR);
-   mktemp(gstWBInfo.listen_fname);
-   unlink(gstWBInfo.listen_fname);
+   if (MkTempFile(gstWBInfo.listen_fname, sizeof(gstWBInfo.listen_fname),
+         tmpDir, TOOL_NAME) == NULL) {
+      fprintf(stderr, "Fail to create '%s' for deserialization.\n",
+            gstWBInfo.listen_fname);
+      return FALSE;
+   }
    if ((gstWBInfo.listen_fp=fopen(gstWBInfo.listen_fname, "w+")) == NULL) {
       fprintf(stderr, "Fail to create '%s' for deserialization.\n",
             gstWBInfo.listen_fname);
@@ -276,8 +280,8 @@ int WBHasReadData(pn_flag, pn_retry)
    
    if ((!(gstWBInfo.BlockRemoteCmdDepth <= 1)) &&  (buff_items(gstWBInfo.bd_commands) > 0) ) 
    {
-    // fprintf(stderr,"gstWBInfo.BlockRemoteCmdDepth > 1 e existem dados no buffer. (WBHasReadData)\n");   
-    // exit(1);
+      /* FIXME fprintf(stderr,"gstWBInfo.BlockRemoteCmdDepth > 1 e existem dados no buffer. (WBHasReadData)\n");
+      exit(1); */
    }
    
    return (gstWBInfo.BlockRemoteCmdDepth <= 1 &&
@@ -361,8 +365,8 @@ int SaveCmd(FP, CmdType, SubCmdPtr, TopSel, BotSel, NumObjs)
       sprintf(gszMsgBox, "%s.\n%s %s.\n\n%s %s.",
             "Warning:  recordCmdIncludeTgifObj is TRUE in SaveCmd()",
             TOOL_NAME, "WhiteBoard may crash",
-            "Please try to reproduce this error and",
-            "send bug report to william@cs.ucla.edu");
+            "Please try to reproduce this error and send bug report to",
+            authorEmailString);
       MsgBox(gszMsgBox, TOOL_NAME, STOP_MB);
       return FALSE;
    } else if (CmdType == CMD_GOTO_PAGE) {
@@ -1191,10 +1195,10 @@ void ProcessRemoteCmd(psz_buf, buf_sz)
             if (cur_cmd_is_wb_clearall) {
                CleanUpDrawingWindow();
                ClearFileInfo(TRUE);
+               SetFileModified(FALSE);
                ClearAndRedrawDrawWindow();
                CheckFileAttrsInLoad();
                Msg("WhiteBoard cleared by peer.");
-               RedrawTitleWindow();
                DelAllPages();
                lastPageNum = 1;
                InitPage();
@@ -1251,8 +1255,90 @@ void ProcessRemoteCmd(psz_buf, buf_sz)
    }
 }
 
+/* =================== Pack and Unpack current state Functions ======= */
+
+#ifdef _TGIF_WB2
+static
+void PackCurrentTGWBState(p_cur_state)
+    CurState *p_cur_state;
+{
+    int auxi, auxj, slen;
+    time_t ticks;
+    int LOCALBUFF_SIZE = 1000;
+
+    char localbuff[LOCALBUFF_SIZE];
+
+
+    ticks = time(NULL);
+    sprintf(localbuff, "%.24s", ctime(&ticks));
+
+    slen = strlen(localbuff);
+
+    p_cur_state->data = ( char* ) malloc( (slen+12) * sizeof(char) );
+
+    memcpy(p_cur_state->data, localbuff, slen);
+
+    for (auxi = slen, auxj = 0; auxi < (slen+10); auxi++, auxj++)
+    {
+        p_cur_state->data[auxi] = auxj;
+    }
+
+    p_cur_state->size = auxi;
+
+}
+
+static
+void UnpackCurrentTGWBState(p_cur_state)
+    CurState *p_cur_state;
+{
+}
+#endif /* _TGIF_WB2 */
+
+void HandleNewUserRequest()
+{
+#ifdef _TGIF_WB2
+   char buf[80];
+   int buf_sz=sizeof(buf);
+
+   /*
+    * Get current tgwb state and establish
+    *         a TCP conection to send the data.
+    */
+   int index=0;
+
+   for (index=0; index < buf_sz-1; index++) {
+      if (read(talkToSelfFiledes[0], &buf[index], 1) != 1) {
+         sprintf(gszMsgBox, TgLoadString(STID_READ_FROM_SELF_PIPE_FAIL), 1,
+               TOOL_NAME),
+         fprintf(stderr, "%s\n", gszMsgBox);
+         index = (-1);
+         break;
+      } else if (buf[index] == '\0') {
+         break;
+      }
+   }
+   if (index == buf_sz-1) {
+      sprintf(gszMsgBox, TgLoadString(STID_READ_FROM_SELF_PIPE_OVERFLOW), 
+            TOOL_NAME),
+      fprintf(stderr, "%s\n", gszMsgBox);
+      index = (-1);
+   }
+   if (index != (-1)) {
+      int conn=0;
+      CurState cur_state;
+
+      memset(&cur_state, 0, sizeof(CurState));
+      sscanf(buf, "%d", &conn);
+      PackCurrentTGWBState(&cur_state);
+      RM_SendCurStatus(conn, (char*)cur_state.data, cur_state.size);
+   }
+#endif /* _TGIF_WB2 */
+}
+
 /* =================== SIGPOLL Handler function =================== */
 
+/* #define DEBUG0 */
+
 #ifdef _TGIF_WB2
 static
 void *ReceivePacket( void *arg )
@@ -1285,9 +1371,17 @@ void *ReceivePacket( void *arg )
 #endif                    
             }
             else
+            {
                 continue;
-        }else
+            }
+        } else if (byread == 0)
+        {
              continue;
+        }
+        else {
+             /* on error, break - no more messages to receive  (shutting down) */
+             break;
+        }
 
 	    /*
          * verifica se a mensagem nao eh dele proprio
@@ -1320,9 +1414,6 @@ void *ReceivePacket( void *arg )
         buff_ins(gstWBInfo.bd_commands, aux);
 
         if(gstWBInfo.BlockRemoteCmdDepth > 0) {
-#ifdef DEBUG0        
-           fprintf(stderr,"no!\n");
-#endif           
 
 #ifdef DEBUG           
            buff_show(gstWBInfo.bd_commands);
@@ -1338,14 +1429,6 @@ void *ReceivePacket( void *arg )
                      TOOL_NAME);
                fprintf(stderr, "%s\n", gszMsgBox);
             }
-            if (c == 'g') {
-               c = 'a';
-            } else {
-               c++;
-            }
-#ifdef DEBUG0                
-            fprintf(stderr,"yes!\n");
-#endif        
         }
     }
     return( NULL );
@@ -1357,21 +1440,29 @@ void *ReceivePacket( void *arg )
 void CleanUpWhiteBoard()
 {
 #ifdef _TGIF_WB2
+   RM_leaveGroup( gstWBInfo.MCastSock, (char*)RM_USE_CURRENT_CONFIG );
    buff_destroy(gstWBInfo.bd_commands);
 #endif /* _TGIF_WB2 */
+
    CleanUpWBSockets();
    CleanUpWBCmds();
    memset(&gstWBInfo, 0, sizeof(struct WhiteBoardRec));
+
 /* CleanUpChat(); */
 }
 
+void handler(int a)
+{
+   fprintf(stderr,"alarm catched in wb.c\n");
+   exit(1);
+}
+
 int InitWhiteBoard()
 {
 #ifdef _TGIF_WB2
-   char localhost_name[31];
-   char pid[6];
-   char logfilename[MAXPATHLENGTH];
-   pthread_t tid;
+   int want_new_user_support=0;
+   CurState cur_state;
+   pthread_t tid=(pthread_t)0;
 #endif /* _TGIF_WB2 */
 
    InitLocalPID(); /* initializes gszLocalPID */
@@ -1404,9 +1495,12 @@ int InitWhiteBoard()
       }
       /* fim do trecho */
 
-      sprintf(gstWBInfo.send_fname, "%sTgifSXXXXXX", TMP_DIR);
-      mktemp(gstWBInfo.send_fname);
-      unlink(gstWBInfo.send_fname);
+      if (MkTempFile(gstWBInfo.send_fname, sizeof(gstWBInfo.send_fname),
+            tmpDir, TOOL_NAME) == NULL) {
+         fprintf(stderr, "Fail to create '%s' for serialization.\n",
+               gstWBInfo.send_fname);
+         exit(-1);
+      }
       if ((gstWBInfo.send_fp=fopen(gstWBInfo.send_fname, "w+")) == NULL) {
          fprintf(stderr, "Fail to create '%s' for serialization.\n",
                gstWBInfo.send_fname);
@@ -1415,18 +1509,37 @@ int InitWhiteBoard()
       /* Creation of multicast socket */
       
       /* sprintf(logfile, "%snome.txt", TMP_DIR); */
-      
-      gethostname(localhost_name, 30);
 
-      strcpy(logfilename,"rmcastlog.");
-      strcat(logfilename,localhost_name);
-      strcat(logfilename,".");
-      sprintf(pid,"%d",(int)getpid());
-      strcat(logfilename,pid);
+      RM_readConfigFile("rmcast.config");
 
-      RM_initialize(0, NULL/* logfilename */);
-      
-      gstWBInfo.MCastSock = RM_joinGroup("225.0.0.5", 5000);
+      /* setting defaults */
+
+      RM_setOption(PIPE, &talkToSelfFiledes);
+      RM_setOption(SHUT_DOWN_ROUTINE, &CleanUpWBSockets);
+
+      RM_initialize();
+
+      RM_getOption(NEW_USER_SUPPORT, (void*)&want_new_user_support);
+
+      if (want_new_user_support)
+      {
+           fprintf(stderr,"Getting the current state.\n");
+
+           RM_getCurState( (char*)RM_USE_CURRENT_CONFIG, RM_USE_CURRENT_CONFIG, &cur_state);
+
+/*
+ *         if (cur_state.size != -1)
+ *
+ *              UnpackCurrentTGWBState(&cur_state);
+ *
+ *         FIXME!  This routine isn't yet implemented.
+ *
+ */
+      }
+
+      gstWBInfo.MCastSock = RM_joinGroup(
+              (char*)RM_USE_CURRENT_CONFIG /* "225.1.2.3" */,
+              RM_USE_CURRENT_CONFIG /* 5000 */ );
 
       gstWBInfo.bd_commands = buff_init (10, WB_PACK, UNSORTED, NULL );
       
